---
hide:
  - toc
---

# PChemDB 🐱

`PChemDB` provides easy access to a number of physical chemistry databases.

## 🌟 Implemented Databases 🌟

- [CRC Handbook of Chemistry and Physics](https://hbcp.chemnetbase.com/contents/ContentsSearch.xhtml?dswid=-1560)
- [Idaho Database of Solution Thermodynamics](https://idst.inl.gov)
- [Journal of Physical and Chemical Reference Data](https://pubs.aip.org/aip/jpr)
